<?php
/**
 * Mog Settings Theme Settings
 *
 * @package      Mog Settings
 * @author       Dee Teal <http://thewebprincess.com/>
 * @copyright    Copyright (c) 2011, Dee Teal
 * @license      http://opensource.org/licenses/gpl-2.0.php GNU Public License
 *
 */


/* Define our constants
------------------------------------------------------------ */

define( 'MOGSETTINGS_SETTINGS_FIELD', 'mog-settings' );


/* Setup default options
------------------------------------------------------------ */

/**
 * mogsettings_default_theme_options function.
 *
 * This function stores the default Mog Settings theme options. It can be filtered using mogsettings_default_theme_options.
 *
 * @return $options, filtered by mogsettings_default_theme_options
 *
 * @since 1.0.0
 *
 */
function mogsettings_default_theme_options() {
	$options = array(
		'mogsettings_facebook_link' 	=> 1,
		'mogsettings_twitter_link' 	=> 1,	
		'mogsettings_google_link' 	=> 1,		
		'mogsettings_fb_url' 	=> '',
		'mogsettings_tw_url' 	=> '',
		'mogsettings_lfm_url' 	=> '',
		'set_wpec_default' 	=> 0
		);
	return apply_filters( 'mogsettings_default_theme_options', $options );
}


/* Sanitize any inputs
------------------------------------------------------------ */

add_action( 'genesis_settings_sanitizer_init', 'mogsettings_sanitize_inputs' );
/**
 * mogsettings_sanitize_inputs function.
 *
 * This function accesses Genesis' sanitization class to sanitize all users inputs and options in the Mog Settings settings area.
 *
 * @since 1.0.0
 *
 */ 
function mogsettings_sanitize_inputs() {
    genesis_add_option_filter( 'no_html', MOGSETTINGS_SETTINGS_FIELD, array(
        'mogsettings_fb_url',
        'mogsettings_tw_url',
        'mogsettings_lfm_url',
        'mogsettings_facebook_link',
        'mogsettings_twitter_link',
        'mogsettings_google_link',
        'set_wpec_default' 
    ) );
}

/* Register our settings and add the options to the database
------------------------------------------------------------ */

add_action( 'admin_init', 'mogsettings_register_settings' );
/**
 * mogsettings_register_settings function.
 *
 * This function registers the settings for use in the Mog Settings theme settings area. It also restores default options when
 * the Reset button is selected or will fire when the set default options for wpec is used.
 *
 * @since 1.0.0
 *
 */
function mogsettings_register_settings() {
	register_setting( MOGSETTINGS_SETTINGS_FIELD, MOGSETTINGS_SETTINGS_FIELD );
	add_option( MOGSETTINGS_SETTINGS_FIELD, mogsettings_default_theme_options() );
	
	if ( genesis_get_option( 'reset', MOGSETTINGS_SETTINGS_FIELD ) ) {
		update_option( MOGSETTINGS_SETTINGS_FIELD, mogsettings_default_theme_options() );
		genesis_admin_redirect( MOGSETTINGS_SETTINGS_FIELD, array( 'reset' => 'true' ) );
		exit;
	}
}

/* I am not sure if Genisis has a save option hook but it would make sense to wrap this in that */
if ($_POST['mog-settings']['set_wpec_default'] == 1){
	mog_set_wpec_defaults();
}
	
/* This function sets the default wp-e-commerce settings */
function mog_set_wpec_defaults() {
	/* button settings */
	update_option('wpsc_addtocart_or_buynow', 0 );
	update_option('wpsc_hide_addtocart_button', 0 );
	/* product page settings */
	update_option('product_view', 'list' );
	update_option('wpsc_display_categories', 1 );
	update_option('wpsc_default_category', 'all' );
	update_option('wpsc_sort_by', 'id' );
	update_option('catsprods_display_type', 0 );
	update_option('show_breadcrumbs', 0 );
	update_option('show_subcatsprods_in_cat', 0 );
	update_option('show_search', 1 );
	update_option('wpsc_replace_page_title', 1 );
	/* shopping cart settings */
	update_option('cart_location', 4 );
	update_option('add_plustax', 0 );
	/* product category settings */
	update_option('wpsc_category_description', 0 );
	update_option('show_category_thumbnails', 1 );
	update_option('wpsc_category_grid_view', 1 );
	update_option('show_category_count', 0 );
	/* thumbnail settings */
	update_option('product_image_width', 120 );
	update_option('product_image_height', 120 );
	update_option('category_image_width', 148 );
	update_option('category_image_height', 148 );
	update_option('single_view_image_width', 250 );
	update_option('single_view_image_height', 250 );
	update_option('wpsc_crop_thumbnails', 0 );
	update_option('show_thumbnails', 1 );
	update_option('show_thumbnails_thickbox', 1 );
	update_option('show_gallery', 1 );
	update_option('wpsc_gallery_image_width', 120 );
	update_option('wpsc_gallery_image_height', 120 );	
}

/* Admin notices for when options are saved/reset
------------------------------------------------------------ */

add_action( 'admin_notices', 'mogsettings_theme_settings_notice' );
/**
 * mogsettings_theme_settings_notice function.
 *
 * This function displays admin notices when the user updates Mog Settings' theme settings area.
 *
 * @since 1.0.0
 *
 */
function mogsettings_theme_settings_notice() {
	if ( ! isset( $_REQUEST['page'] ) || $_REQUEST['page'] != MOGSETTINGS_SETTINGS_FIELD )
		return;

	if ( isset( $_REQUEST['reset'] ) && 'true' == $_REQUEST['reset'] )
		echo '<div id="message" class="updated"><p><strong>' . __( 'Settings reset.', 'genesis' ) . '</strong></p></div>';
	elseif ( isset( $_REQUEST['settings-updated'] ) && 'true' == $_REQUEST['settings-updated'] )
		echo '<div id="message" class="updated"><p><strong>' . __( 'Settings saved.', 'genesis' ) . '</strong></p></div>';
}


/* Register our theme options page
------------------------------------------------------------ */

add_action( 'admin_menu', 'mogsettings_theme_options' );
/**
 * mogsettings_theme_options function.
 *
 * This function registers the Mog Settings settings page and prepares the styles, scripts and metaboxes to be loaded.
 *
 * @global $_mogsettings_settings_pagehook
 *
 * @since 1.0.0
 *
 */
function mogsettings_theme_options() {
	global $_mogsettings_settings_pagehook;
	$_mogsettings_settings_pagehook = add_submenu_page( 'genesis', 'myTunes Settings', 'myTunes Settings', 'edit_theme_options', MOGSETTINGS_SETTINGS_FIELD, 'mogsettings_theme_options_page' );

	//add_action( 'load-'.$_mogsettings_settings_pagehook, 'mogsettings_settings_styles' );
	add_action( 'load-'.$_mogsettings_settings_pagehook, 'mogsettings_settings_scripts' );
	add_action( 'load-'.$_mogsettings_settings_pagehook, 'mogsettings_settings_boxes' );
}


/* Setup our scripts
------------------------------------------------------------ */

/**
 * mogsettings_settings_scripts function.
 *
 * This function enqueues the scripts needed for the Mog Settings settings page.
 *
 * @global $_mogsettings_settings_pagehook
 *
 * @since 1.0.0
 *
 */
function mogsettings_settings_scripts() {	
	global $_mogsettings_settings_pagehook;
	wp_enqueue_script( 'common' );
	wp_enqueue_script( 'wp-lists' );
	wp_enqueue_script( 'postbox' );
}


/* Setup our metaboxes
------------------------------------------------------------ */

/**
 * mogsettings_settings_boxes function.
 *
 * This function sets up the metaboxes to be populated by their respective callback functions.
 *
 * @global $_mogsettings_settings_pagehook
 *
 * @since 1.0.0
 *
 */
function mogsettings_settings_boxes() {
	global $_mogsettings_settings_pagehook;
	add_meta_box( 'mogsettings-social-box', __( 'myTunes Settings Social Sharing', 'genesis' ), 'mogsettings_social_metabox', $_mogsettings_settings_pagehook, 'main' );
    add_meta_box('mog-social-settings', 'Social Links', 'mog_social_settings_box', $_mogsettings_settings_pagehook, 'main');	
     add_meta_box('mog-wpec-settings', 'WP-e-Commerce Settings', 'mog_wpec_settings_box', $_mogsettings_settings_pagehook, 'main');	
}
 
/**




/* Add our custom post metabox for social sharing
------------------------------------------------------------ */

/**
 * mogsettings_social_metabox function.
 *
 * Callback function for the Mog Settings Social Sharing metabox.
 *
 * @since 1.0.0
 *
 */
function mogsettings_social_metabox() { ?>

	<p><?php _e( 'Check any of the following if you want Facebook, Twitter or Google+ buttons for your posts or pages.', 'genesis' ); ?></p>
	<table class="form-table mogsettings-social">
		<tbody>
		<tr valign="top"><th scope="row"><strong>Facebook Like Button</strong></th></tr>
			<tr valign="top">
				<th scope="row">
				
					<input type="radio" name="<?php echo MOGSETTINGS_SETTINGS_FIELD; ?>[mogsettings_facebook_link]" id="<?php echo MOGSETTINGS_SETTINGS_FIELD; ?>[mogsettings_facebook_link]" value="1" <?php checked( 1, genesis_get_option( 'mogsettings_facebook_link', MOGSETTINGS_SETTINGS_FIELD ) ); ?> /> <label for="<?php echo MOGSETTINGS_SETTINGS_FIELD; ?>[mogsettings_facebook_link]"><?php _e( 'Posts and Pages', 'genesis' ); ?></label>
					
					<input type="radio" name="<?php echo MOGSETTINGS_SETTINGS_FIELD; ?>[mogsettings_facebook_link]" id="<?php echo MOGSETTINGS_SETTINGS_FIELD; ?>[mogsettings_facebook_link]" value="2" <?php checked( 2, genesis_get_option( 'mogsettings_facebook_link', MOGSETTINGS_SETTINGS_FIELD ) ); ?> /> <label for="<?php echo MOGSETTINGS_SETTINGS_FIELD; ?>[mogsettings_facebook_links_page]"><?php _e( 'Just Pages', 'genesis' ); ?></label>
					
					<input type="radio" name="<?php echo MOGSETTINGS_SETTINGS_FIELD; ?>[mogsettings_facebook_link]" id="<?php echo MOGSETTINGS_SETTINGS_FIELD; ?>[mogsettings_facebook_link]" value="3" <?php checked( 3, genesis_get_option( 'mogsettings_facebook_link', MOGSETTINGS_SETTINGS_FIELD ) ); ?> /> <label for="<?php echo MOGSETTINGS_SETTINGS_FIELD; ?>[mogsettings_facebook_links_post]"><?php _e( 'Just Posts', 'genesis' ); ?></label>
					
				</th>
			</tr>
			<tr valign="top"><th scope="row"><strong>Twitter Retweet Button</strong></th></tr>
			<tr valign="top">
				<th scope="row">
					<input type="radio" name="<?php echo MOGSETTINGS_SETTINGS_FIELD; ?>[mogsettings_twitter_link]" id="<?php echo MOGSETTINGS_SETTINGS_FIELD; ?>[mogsettings_twitter_link]" value="1" <?php checked( 1, genesis_get_option( 'mogsettings_twitter_link', MOGSETTINGS_SETTINGS_FIELD ) ); ?> /> <label for="<?php echo MOGSETTINGS_SETTINGS_FIELD; ?>[mogsettings_twitter_link]"><?php _e( 'Posts and Pages', 'genesis' ); ?></label>
					<input type="radio" name="<?php echo MOGSETTINGS_SETTINGS_FIELD; ?>[mogsettings_twitter_link]" id="<?php echo MOGSETTINGS_SETTINGS_FIELD; ?>[mogsettings_twitter_link]" value="2" <?php checked( 2, genesis_get_option( 'mogsettings_twitter_link', MOGSETTINGS_SETTINGS_FIELD ) ); ?> /> <label for="<?php echo MOGSETTINGS_SETTINGS_FIELD; ?>[mogsettings_twitter_link]"><?php _e( 'Just Pages', 'genesis' ); ?></label>
					<input type="radio" name="<?php echo MOGSETTINGS_SETTINGS_FIELD; ?>[mogsettings_twitter_link]" id="<?php echo MOGSETTINGS_SETTINGS_FIELD; ?>[mogsettings_twitter_link]" value="3" <?php checked( 3, genesis_get_option( 'mogsettings_twitter_link', MOGSETTINGS_SETTINGS_FIELD ) ); ?> /> <label for="<?php echo MOGSETTINGS_SETTINGS_FIELD; ?>[mogsettings_twitter_link]"><?php _e( 'Just Posts', 'genesis' ); ?></label>
				</th>
			</tr>
		<tr valign="top"><th scope="row"><strong>Google +1 Button</strong></th></tr>

			<tr valign="top">
				<th scope="row">
					<input type="radio" name="<?php echo MOGSETTINGS_SETTINGS_FIELD; ?>[mogsettings_google_link]" id="<?php echo MOGSETTINGS_SETTINGS_FIELD; ?>[mogsettings_google_link]" value="1" <?php checked( 1, genesis_get_option( 'mogsettings_google_link', MOGSETTINGS_SETTINGS_FIELD ) ); ?> /> <label for="<?php echo MOGSETTINGS_SETTINGS_FIELD; ?>[mogsettings_google_link]"><?php _e( 'Posts and Pages', 'genesis' ); ?></label>
					<input type="radio" name="<?php echo MOGSETTINGS_SETTINGS_FIELD; ?>[mogsettings_google_link]" id="<?php echo MOGSETTINGS_SETTINGS_FIELD; ?>[mogsettings_google_link]" value="2" <?php checked( 2, genesis_get_option( 'mogsettings_google_link', MOGSETTINGS_SETTINGS_FIELD ) ); ?> /> <label for="<?php echo MOGSETTINGS_SETTINGS_FIELD; ?>[mogsettings_google_links_page]"><?php _e( 'Just Pages', 'genesis' ); ?></label>
					<input type="radio" name="<?php echo MOGSETTINGS_SETTINGS_FIELD; ?>[mogsettings_google_link]" id="<?php echo MOGSETTINGS_SETTINGS_FIELD; ?>[mogsettings_google_link]" value="3" <?php checked( 3, genesis_get_option( 'mogsettings_google_link', MOGSETTINGS_SETTINGS_FIELD ) ); ?> /> <label for="<?php echo MOGSETTINGS_SETTINGS_FIELD; ?>[mogsettings_google_link]"><?php _e( 'Just Posts', 'genesis' ); ?></label>
				</th>
			</tr>
		</tbody>
	</table>
	
<?php }

/**
 * Create Metabox
 *
 */
 
function mog_social_settings_box() {
    ?>
 
    <p>Twitter URL:<br />
    <input type="text" name="<?php echo MOGSETTINGS_SETTINGS_FIELD; ?>[mogsettings_tw_url]" value="<?php echo esc_attr( genesis_get_option('mogsettings_tw_url', MOGSETTINGS_SETTINGS_FIELD) ); ?>" size="50" /> </p>
 
    <p>Facebook URL:<br />
    <input type="text" name="<?php echo MOGSETTINGS_SETTINGS_FIELD; ?>[mogsettings_fb_url]" value="<?php echo esc_attr( genesis_get_option('mogsettings_fb_url', MOGSETTINGS_SETTINGS_FIELD) ); ?>" size="50" /> </p>

    <p>Last FM URL:<br />
    <input type="text" name="<?php echo MOGSETTINGS_SETTINGS_FIELD; ?>[mogsettings_lfm_url]" value="<?php echo esc_attr( genesis_get_option('mogsettings_lfm_url', MOGSETTINGS_SETTINGS_FIELD) ); ?>" size="50" /> </p>
    <?php
}

function mog_wpec_settings_box() {
	?>
	<p><!--These are the MOG theme WP e-Commerce specific settings.-->
	
	<label for="<?php echo MOGSETTINGS_SETTINGS_FIELD; ?>[set_wpec_default]">Use the recommended WP-e-Commerce presentation settings:</label>
	<input type="radio" name="<?php echo MOGSETTINGS_SETTINGS_FIELD; ?>[set_wpec_default]" id="<?php echo MOGSETTINGS_SETTINGS_FIELD; ?>[set_wpec_default]" value="1" <?php checked( 1, genesis_get_option( 'set_wpec_default', MOGSETTINGS_SETTINGS_FIELD ) ); ?> /> <label for="<?php echo MOGSETTINGS_SETTINGS_FIELD; ?>[set_wpec_default]"><?php _e( 'Yes', 'genesis' ); ?></label>
						
	<input type="radio" name="<?php echo MOGSETTINGS_SETTINGS_FIELD; ?>[set_wpec_default]" id="<?php echo MOGSETTINGS_SETTINGS_FIELD; ?>[set_wpec_default]" value="0" <?php checked( 0, genesis_get_option( 'set_wpec_default', MOGSETTINGS_SETTINGS_FIELD ) ); ?> /> <label for="<?php echo MOGSETTINGS_SETTINGS_FIELD; ?>[set_wpec_default]"><?php _e( 'No', 'genesis' ); ?></label></p>
	<p class="description">By choosing Yes some of your WP-e-Commerce Presentation settings will be reset to the recommended settings for the myTunes theme.</p>
	<?php
}


/* Set the screen layout to one column
------------------------------------------------------------ */

add_filter( 'screen_layout_columns', 'mogsettings_settings_layout_columns', 10, 2 );
/**
 * mogsettings_settings_layout_columns function.
 *
 * This function sets the column layout to one for the Mog Settings settings page.
 *
 * @param mixed $columns
 * @param mixed $screen
 * @return $columns
 *
 * @since 1.0.0
 *
 */
function mogsettings_settings_layout_columns( $columns, $screen ) {
	global $_mogsettings_settings_pagehook;
	if ( $screen == $_mogsettings_settings_pagehook ) {
		$columns[$_mogsettings_settings_pagehook] = 1;
	}
	return $columns;
}


/* Build our theme options page
------------------------------------------------------------ */

/**
 * mogsettings_theme_options_page function.
 *
 * This function displays the content for the Mog Settings settings page, builds the forms and outputs the metaboxes.
 *
 * @global $_mogsettings_settings_pagehook
 * @global $screen_layout_columns
 *
 * @since 1.0.0
 *
 */
function mogsettings_theme_options_page() { 

	global $_mogsettings_settings_pagehook, $screen_layout_columns;
	$width = "width: 99%;";
	$hide2 = $hide3 = " display: none;";
	?>	
	
	<div id="mogsettings" class="wrap genesis-metaboxes">
		<form method="post" action="options.php">
		
			<?php wp_nonce_field( 'closedpostboxes', 'closedpostboxesnonce', false ); ?>
			<?php wp_nonce_field( 'meta-box-order', 'meta-box-order-nonce', false ); ?>
			<?php settings_fields( MOGSETTINGS_SETTINGS_FIELD ); ?>
			
			<?php screen_icon( 'options-general' ); ?>
			<h2>			
				<?php _e( 'myTunes - Theme Settings', 'genesis' ); ?>
				<input type="submit" class="button-primary genesis-h2-button" value="<?php _e( 'Save Settings', 'genesis' ) ?>" />
				<input type="submit" class="button-highlighted genesis-h2-button" name="<?php echo MOGSETTINGS_SETTINGS_FIELD; ?>[reset]" value="<?php _e( 'Reset Settings', 'genesis' ); ?>" onclick="return genesis_confirm('<?php echo esc_js( __( 'Are you sure you want to reset?', 'genesis' ) ); ?>');" />
			</h2>
		
			<div class="metabox-holder">
				<div class="postbox-container" style="<?php echo $width; ?>">
					<?php do_meta_boxes( $_mogsettings_settings_pagehook, 'main', null ); ?>
				</div>
			</div>
			<h2 style="float:right">
				<input type="submit" class="button-primary genesis-h2-button" value="<?php _e( 'Save Settings', 'genesis' ) ?>" />
				<input type="submit" class="button-highlighted genesis-h2-button" name="<?php echo MOGSETTINGS_SETTINGS_FIELD; ?>[reset]" value="<?php _e( 'Reset Settings', 'genesis' ); ?>" onclick="return genesis_confirm('<?php echo esc_js( __( 'Are you sure you want to reset?', 'genesis' ) ); ?>');" />
			</h2>
		</form>
	</div>
	<script type="text/javascript">
		//<![CDATA[
		jQuery(document).ready( function($) {
			// close postboxes that should be closed
			$('.if-js-closed').removeClass('if-js-closed').addClass('closed');
			// postboxes setup
			postboxes.add_postbox_toggles('<?php echo $_mogsettings_settings_pagehook; ?>');
		});
		//]]>
	</script>

<?php }